==> turretcss-5.1.3.tgz: package/docs/utility/background-color.md <==
---
layout: docs
title: Background Color
description: null
---

## Background Color

| Class                      | Description                                          |
| -------------------------- | ---------------------------------------------------- |
| `background-transparent`   | Applies `background: transparent;` to element        |
| `background-current-color` | Applies `background-color: currentColor;` to element |
| `background-inherit`       | Applies `background-color: inherit;` to element      |

<div class="padding-xs background">Base Background</div>

```html
<div class="background">...</div>
```

## Colors

<div class="padding-xs color-black background-white">White</div>
<div class="padding-xs color-white background-black">Black</div>

```html
<div class="background-white">...</div>
<div class="background-black">...</div>
```

## Shades

### Light

<div class="padding-xs color-dark background-light">Light</div>
<div class="palette">
  <div class="padding-xs color-dark background-light-50">Light<br>50</div>
  <div class="padding-xs color-dark background-light-100">Light<br>100</div>
  <div class="padding-xs color-dark background-light-200">Light<br>200</div>
  <div class="padding-xs color-dark background-light-300">Light<br>300</div>
  <div class="padding-xs color-dark background-light-400">Light<br>400</div>
  <div class="padding-xs color-dark background-light-500">Light<br>500</div>
  <div class="padding-xs color-dark background-light-600">Light<br>600</div>
  <div class="padding-xs color-dark background-light-700">Light<br>700</div>
  <div class="padding-xs color-dark background-light-800">Light<br>800</div>
  <div class="padding-xs color-dark background-light-900">Light<br>900</div>
</div>

```html
<div class="background-light">...</div>
<div class="background-light-50">...</div>
<div class="background-light-100">...</div>
<div class="background-light-200">...</div>
<div class="background-light-300">...</div>
<div class="background-light-400">...</div>
<div class="background-light-500">...</div>
<div class="background-light-600">...</div>
<div class="background-light-700">...</div>
<div class="background-light-800">...</div>
<div class="background-light-900">...</div>
```

### Grey

<div class="padding-xs color-white background-grey">Grey</div>
<div class="palette">
  <div class="padding-xs color-white background-grey-50">Grey<br>50</div>
  <div class="padding-xs color-white background-grey-100">Grey<br>100</div>
  <div class="padding-xs color-white background-grey-200">Grey<br>200</div>
  <div class="padding-xs color-white background-grey-300">Grey<br>300</div>
  <div class="padding-xs color-white background-grey-400">Grey<br>400</div>
  <div class="padding-xs color-white background-grey-500">Grey<br>500</div>
  <div class="padding-xs color-white background-grey-600">Grey<br>600</div>
  <div class="padding-xs color-white background-grey-700">Grey<br>700</div>
  <div class="padding-xs color-white background-grey-800">Grey<br>800</div>
  <div class="padding-xs color-white background-grey-900">Grey<br>900</div>
</div>

```html
<div class="background-grey">...</div>
<div class="background-grey-50">...</div>
<div class="background-grey-100">...</div>
<div class="background-grey-200">...</div>
<div class="background-grey-300">...</div>
<div class="background-grey-400">...</div>
<div class="background-grey-500">...</div>
<div class="background-grey-600">...</div>
<div class="background-grey-700">...</div>
<div class="background-grey-800">...</div>
<div class="background-grey-900">...</div>
```

### Dark

<div class="padding-xs color-white background-dark">Dark</div>
<div class="palette">
  <div class="padding-xs color-white background-dark-50">Dark<br>50</div>
  <div class="padding-xs color-white background-dark-100">Dark<br>100</div>
  <div class="padding-xs color-white background-dark-200">Dark<br>200</div>
  <div class="padding-xs color-white background-dark-300">Dark<br>300</div>
  <div class="padding-xs color-white background-dark-400">Dark<br>400</div>
  <div class="padding-xs color-white background-dark-500">Dark<br>500</div>
  <div class="padding-xs color-white background-dark-600">Dark<br>600</div>
  <div class="padding-xs color-white background-dark-700">Dark<br>700</div>
  <div class="padding-xs color-white background-dark-800">Dark<br>800</div>
  <div class="padding-xs color-white background-dark-900">Dark<br>900</div>
</div>

```html
<div class="background-dark">...</div>
<div class="background-dark-50">...</div>
<div class="background-dark-100">...</div>
<div class="background-dark-200">...</div>
<div class="background-dark-300">...</div>
<div class="background-dark-400">...</div>
<div class="background-dark-500">...</div>
<div class="background-dark-600">...</div>
<div class="background-dark-700">...</div>
<div class="background-dark-800">...</div>
<div class="background-dark-900">...</div>
```

## Palettes

### Primary

<div class="padding-xs color-white background-primary">Primary</div>
<div class="palette">
  <div class="padding-xs color-white background-primary-50">Primary<br>50</div>
  <div class="padding-xs color-white background-primary-100">Primary<br>100</div>
  <div class="padding-xs color-white background-primary-200">Primary<br>200</div>
  <div class="padding-xs color-white background-primary-300">Primary<br>300</div>
  <div class="padding-xs color-white background-primary-400">Primary<br>400</div>
  <div class="padding-xs color-white background-primary-500">Primary<br>500</div>
  <div class="padding-xs color-white background-primary-600">Primary<br>600</div>
  <div class="padding-xs color-white background-primary-700">Primary<br>700</div>
  <div class="padding-xs color-white background-primary-800">Primary<br>800</div>
  <div class="padding-xs color-white background-primary-900">Primary<br>900</div>
</div>

```html
<div class="background-primary">...</div>
<div class="background-primary-50">...</div>
<div class="background-primary-100">...</div>
<div class="background-primary-200">...</div>
<div class="background-primary-300">...</div>
<div class="background-primary-400">...</div>
<div class="background-primary-500">...</div>
<div class="background-primary-600">...</div>
<div class="background-primary-700">...</div>
<div class="background-primary-800">...</div>
<div class="background-primary-900">...</div>
```

### Secondary

<div class="padding-xs color-white background-secondary">Secondary</div>
<div class="palette">
  <div class="padding-xs color-white background-secondary-50">Secondary<br>50</div>
  <div class="padding-xs color-white background-secondary-100">Secondary<br>100</div>
  <div class="padding-xs color-white background-secondary-200">Secondary<br>200</div>
  <div class="padding-xs color-white background-secondary-300">Secondary<br>300</div>
  <div class="padding-xs color-white background-secondary-400">Secondary<br>400</div>
  <div class="padding-xs color-white background-secondary-500">Secondary<br>500</div>
  <div class="padding-xs color-white background-secondary-600">Secondary<br>600</div>
  <div class="padding-xs color-white background-secondary-700">Secondary<br>700</div>
  <div class="padding-xs color-white background-secondary-800">Secondary<br>800</div>
  <div class="padding-xs color-white background-secondary-900">Secondary<br>900</div>
</div>

```html
<div class="background-secondary">...</div>
<div class="background-secondary-50">...</div>
<div class="background-secondary-100">...</div>
<div class="background-secondary-200">...</div>
<div class="background-secondary-300">...</div>
<div class="background-secondary-400">...</div>
<div class="background-secondary-500">...</div>
<div class="background-secondary-600">...</div>
<div class="background-secondary-700">...</div>
<div class="background-secondary-800">...</div>
<div class="background-secondary-900">...</div>
```

### Tertiary

<div class="padding-xs color-white background-tertiary">Tertiary</div>
<div class="palette">
  <div class="padding-xs color-white background-tertiary-50">Tertiary<br>50</div>
  <div class="padding-xs color-white background-tertiary-100">Tertiary<br>100</div>
  <div class="padding-xs color-white background-tertiary-200">Tertiary<br>200</div>
  <div class="padding-xs color-white background-tertiary-300">Tertiary<br>300</div>
  <div class="padding-xs color-white background-tertiary-400">Tertiary<br>400</div>
  <div class="padding-xs color-white background-tertiary-500">Tertiary<br>500</div>
  <div class="padding-xs color-white background-tertiary-600">Tertiary<br>600</div>
  <div class="padding-xs color-white background-tertiary-700">Tertiary<br>700</div>
  <div class="padding-xs color-white background-tertiary-800">Tertiary<br>800</div>
  <div class="padding-xs color-white background-tertiary-900">Tertiary<br>900</div>
</div>

```html
<div class="background-tertiary">...</div>
<div class="background-tertiary-50">...</div>
<div class="background-tertiary-100">...</div>
<div class="background-tertiary-200">...</div>
<div class="background-tertiary-300">...</div>
<div class="background-tertiary-400">...</div>
<div class="background-tertiary-500">...</div>
<div class="background-tertiary-600">...</div>
<div class="background-tertiary-700">...</div>
<div class="background-tertiary-800">...</div>
<div class="background-tertiary-900">...</div>
```

## Indicators

### Error

<div class="padding-xs color-white background-error">Error</div>
<div class="palette">
  <div class="padding-xs color-white background-error-50">Error<br>50</div>
  <div class="padding-xs color-white background-error-100">Error<br>100</div>
  <div class="padding-xs color-white background-error-200">Error<br>200</div>
  <div class="padding-xs color-white background-error-300">Error<br>300</div>
  <div class="padding-xs color-white background-error-400">Error<br>400</div>
  <div class="padding-xs color-white background-error-500">Error<br>500</div>
  <div class="padding-xs color-white background-error-600">Error<br>600</div>
  <div class="padding-xs color-white background-error-700">Error<br>700</div>
  <div class="padding-xs color-white background-error-800">Error<br>800</div>
  <div class="padding-xs color-white background-error-900">Error<br>900</div>
</div>

```html
<div class="background-error">...</div>
<div class="background-error-50">...</div>
<div class="background-error-100">...</div>
<div class="background-error-200">...</div>
<div class="background-error-300">...</div>
<div class="background-error-400">...</div>
<div class="background-error-500">...</div>
<div class="background-error-600">...</div>
<div class="background-error-700">...</div>
<div class="background-error-800">...</div>
<div class="background-error-900">...</div>
```

### Warning

<div class="padding-xs color-white background-warning">Warning</div>
<div class="palette">
  <div class="padding-xs color-white background-warning-50">Warning<br>50</div>
  <div class="padding-xs color-white background-warning-100">Warning<br>100</div>
  <div class="padding-xs color-white background-warning-200">Warning<br>200</div>
  <div class="padding-xs color-white background-warning-300">Warning<br>300</div>
  <div class="padding-xs color-white background-warning-400">Warning<br>400</div>
  <div class="padding-xs color-white background-warning-500">Warning<br>500</div>
  <div class="padding-xs color-white background-warning-600">Warning<br>600</div>
  <div class="padding-xs color-white background-warning-700">Warning<br>700</div>
  <div class="padding-xs color-white background-warning-800">Warning<br>800</div>
  <div class="padding-xs color-white background-warning-900">Warning<br>900</div>
</div>

```html
<div class="background-warning">...</div>
<div class="background-warning-50">...</div>
<div class="background-warning-100">...</div>
<div class="background-warning-200">...</div>
<div class="background-warning-300">...</div>
<div class="background-warning-400">...</div>
<div class="background-warning-500">...</div>
<div class="background-warning-600">...</div>
<div class="background-warning-700">...</div>
<div class="background-warning-800">...</div>
<div class="background-warning-900">...</div>
```

### Success

<div class="padding-xs color-white background-success">Success</div>
<div class="palette">
  <div class="padding-xs color-white background-success-50">Success<br>50</div>
  <div class="padding-xs color-white background-success-100">Success<br>100</div>
  <div class="padding-xs color-white background-success-200">Success<br>200</div>
  <div class="padding-xs color-white background-success-300">Success<br>300</div>
  <div class="padding-xs color-white background-success-400">Success<br>400</div>
  <div class="padding-xs color-white background-success-500">Success<br>500</div>
  <div class="padding-xs color-white background-success-600">Success<br>600</div>
  <div class="padding-xs color-white background-success-700">Success<br>700</div>
  <div class="padding-xs color-white background-success-800">Success<br>800</div>
  <div class="padding-xs color-white background-success-900">Success<br>900</div>
</div>

```html
<div class="background-success">...</div>
<div class="background-success-50">...</div>
<div class="background-success-100">...</div>
<div class="background-success-200">...</div>
<div class="background-success-300">...</div>
<div class="background-success-400">...</div>
<div class="background-success-500">...</div>
<div class="background-success-600">...</div>
<div class="background-success-700">...</div>
<div class="background-success-800">...</div>
<div class="background-success-900">...</div>
```

### Info

<div class="padding-xs color-white background-info">Info</div>
<div class="palette">
  <div class="padding-xs color-white background-info-50">Info<br>50</div>
  <div class="padding-xs color-white background-info-100">Info<br>100</div>
  <div class="padding-xs color-white background-info-200">Info<br>200</div>
  <div class="padding-xs color-white background-info-300">Info<br>300</div>
  <div class="padding-xs color-white background-info-400">Info<br>400</div>
  <div class="padding-xs color-white background-info-500">Info<br>500</div>
  <div class="padding-xs color-white background-info-600">Info<br>600</div>
  <div class="padding-xs color-white background-info-700">Info<br>700</div>
  <div class="padding-xs color-white background-info-800">Info<br>800</div>
  <div class="padding-xs color-white background-info-900">Info<br>900</div>
</div>

```html
<div class="background-info">...</div>
<div class="background-info-50">...</div>
<div class="background-info-100">...</div>
<div class="background-info-200">...</div>
<div class="background-info-300">...</div>
<div class="background-info-400">...</div>
<div class="background-info-500">...</div>
<div class="background-info-600">...</div>
<div class="background-info-700">...</div>
<div class="background-info-800">...</div>
<div class="background-info-900">...</div>
```

==> turretcss-5.2.1.tgz: package/docs/utility/background-color.md <==
---
layout: docs
title: Background Color
description: null
---

| Class                      | Description                                          |
| -------------------------- | ---------------------------------------------------- |
| `background-transparent`   | Applies `background: transparent;` to element        |
| `background-current-color` | Applies `background-color: currentColor;` to element |
| `background-inherit`       | Applies `background-color: inherit;` to element      |

<div class="padding-xs background">Base Background</div>

```html
<div class="background">...</div>
```

## Colors

<div class="padding-xs color-black background-white">White</div>
<div class="padding-xs color-white background-black">Black</div>

```html
<div class="background-white">...</div>
<div class="background-black">...</div>
```

## Shades

### Light

<div class="padding-xs color-dark background-light">Light</div>
<div class="palette">
  <div class="padding-xs color-dark background-light-50">Light<br>50</div>
  <div class="padding-xs color-dark background-light-100">Light<br>100</div>
  <div class="padding-xs color-dark background-light-200">Light<br>200</div>
  <div class="padding-xs color-dark background-light-300">Light<br>300</div>
  <div class="padding-xs color-dark background-light-400">Light<br>400</div>
  <div class="padding-xs color-dark background-light-500">Light<br>500</div>
  <div class="padding-xs color-dark background-light-600">Light<br>600</div>
  <div class="padding-xs color-dark background-light-700">Light<br>700</div>
  <div class="padding-xs color-dark background-light-800">Light<br>800</div>
  <div class="padding-xs color-white background-light-900">Light<br>900</div>
</div>

```html
<div class="background-light">...</div>
<div class="background-light-50">...</div>
<div class="background-light-100">...</div>
<div class="background-light-200">...</div>
<div class="background-light-300">...</div>
<div class="background-light-400">...</div>
<div class="background-light-500">...</div>
<div class="background-light-600">...</div>
<div class="background-light-700">...</div>
<div class="background-light-800">...</div>
<div class="background-light-900">...</div>
```

### Grey

<div class="padding-xs color-white background-grey">Grey</div>
<div class="palette">
  <div class="padding-xs color-dark background-grey-50">Grey<br>50</div>
  <div class="padding-xs color-dark background-grey-100">Grey<br>100</div>
  <div class="padding-xs color-dark background-grey-200">Grey<br>200</div>
  <div class="padding-xs color-dark background-grey-300">Grey<br>300</div>
  <div class="padding-xs color-white background-grey-400">Grey<br>400</div>
  <div class="padding-xs color-white background-grey-500">Grey<br>500</div>
  <div class="padding-xs color-white background-grey-600">Grey<br>600</div>
  <div class="padding-xs color-white background-grey-700">Grey<br>700</div>
  <div class="padding-xs color-white background-grey-800">Grey<br>800</div>
  <div class="padding-xs color-white background-grey-900">Grey<br>900</div>
</div>

```html
<div class="background-grey">...</div>
<div class="background-grey-50">...</div>
<div class="background-grey-100">...</div>
<div class="background-grey-200">...</div>
<div class="background-grey-300">...</div>
<div class="background-grey-400">...</div>
<div class="background-grey-500">...</div>
<div class="background-grey-600">...</div>
<div class="background-grey-700">...</div>
<div class="background-grey-800">...</div>
<div class="background-grey-900">...</div>
```

### Dark

<div class="padding-xs color-white background-dark">Dark</div>
<div class="palette">
  <div class="padding-xs color-dark background-dark-50">Dark<br>50</div>
  <div class="padding-xs color-dark background-dark-100">Dark<br>100</div>
  <div class="padding-xs color-dark background-dark-200">Dark<br>200</div>
  <div class="padding-xs color-dark background-dark-300">Dark<br>300</div>
  <div class="padding-xs color-white background-dark-400">Dark<br>400</div>
  <div class="padding-xs color-white background-dark-500">Dark<br>500</div>
  <div class="padding-xs color-white background-dark-600">Dark<br>600</div>
  <div class="padding-xs color-white background-dark-700">Dark<br>700</div>
  <div class="padding-xs color-white background-dark-800">Dark<br>800</div>
  <div class="padding-xs color-white background-dark-900">Dark<br>900</div>
</div>

```html
<div class="background-dark">...</div>
<div class="background-dark-50">...</div>
<div class="background-dark-100">...</div>
<div class="background-dark-200">...</div>
<div class="background-dark-300">...</div>
<div class="background-dark-400">...</div>
<div class="background-dark-500">...</div>
<div class="background-dark-600">...</div>
<div class="background-dark-700">...</div>
<div class="background-dark-800">...</div>
<div class="background-dark-900">...</div>
```

## Palettes

### Primary

<div class="padding-xs color-white background-primary">Primary</div>
<div class="palette">
  <div class="padding-xs color-dark background-primary-50">Primary<br>50</div>
  <div class="padding-xs color-dark background-primary-100">Primary<br>100</div>
  <div class="padding-xs color-dark background-primary-200">Primary<br>200</div>
  <div class="padding-xs color-dark background-primary-300">Primary<br>300</div>
  <div class="padding-xs color-white background-primary-400">Primary<br>400</div>
  <div class="padding-xs color-white background-primary-500">Primary<br>500</div>
  <div class="padding-xs color-white background-primary-600">Primary<br>600</div>
  <div class="padding-xs color-white background-primary-700">Primary<br>700</div>
  <div class="padding-xs color-white background-primary-800">Primary<br>800</div>
  <div class="padding-xs color-white background-primary-900">Primary<br>900</div>
</div>

```html
<div class="background-primary">...</div>
<div class="background-primary-50">...</div>
<div class="background-primary-100">...</div>
<div class="background-primary-200">...</div>
<div class="background-primary-300">...</div>
<div class="background-primary-400">...</div>
<div class="background-primary-500">...</div>
<div class="background-primary-600">...</div>
<div class="background-primary-700">...</div>
<div class="background-primary-800">...</div>
<div class="background-primary-900">...</div>
```

### Secondary

<div class="padding-xs color-white background-secondary">Secondary</div>
<div class="palette">
  <div class="padding-xs color-dark background-secondary-50">Secondary<br>50</div>
  <div class="padding-xs color-dark background-secondary-100">Secondary<br>100</div>
  <div class="padding-xs color-dark background-secondary-200">Secondary<br>200</div>
  <div class="padding-xs color-dark background-secondary-300">Secondary<br>300</div>
  <div class="padding-xs color-white background-secondary-400">Secondary<br>400</div>
  <div class="padding-xs color-white background-secondary-500">Secondary<br>500</div>
  <div class="padding-xs color-white background-secondary-600">Secondary<br>600</div>
  <div class="padding-xs color-white background-secondary-700">Secondary<br>700</div>
  <div class="padding-xs color-white background-secondary-800">Secondary<br>800</div>
  <div class="padding-xs color-white background-secondary-900">Secondary<br>900</div>
</div>

```html
<div class="background-secondary">...</div>
<div class="background-secondary-50">...</div>
<div class="background-secondary-100">...</div>
<div class="background-secondary-200">...</div>
<div class="background-secondary-300">...</div>
<div class="background-secondary-400">...</div>
<div class="background-secondary-500">...</div>
<div class="background-secondary-600">...</div>
<div class="background-secondary-700">...</div>
<div class="background-secondary-800">...</div>
<div class="background-secondary-900">...</div>
```

### Tertiary

<div class="padding-xs color-white background-tertiary">Tertiary</div>
<div class="palette">
  <div class="padding-xs color-dark background-tertiary-50">Tertiary<br>50</div>
  <div class="padding-xs color-dark background-tertiary-100">Tertiary<br>100</div>
  <div class="padding-xs color-dark background-tertiary-200">Tertiary<br>200</div>
  <div class="padding-xs color-dark background-tertiary-300">Tertiary<br>300</div>
  <div class="padding-xs color-white background-tertiary-400">Tertiary<br>400</div>
  <div class="padding-xs color-white background-tertiary-500">Tertiary<br>500</div>
  <div class="padding-xs color-white background-tertiary-600">Tertiary<br>600</div>
  <div class="padding-xs color-white background-tertiary-700">Tertiary<br>700</div>
  <div class="padding-xs color-white background-tertiary-800">Tertiary<br>800</div>
  <div class="padding-xs color-white background-tertiary-900">Tertiary<br>900</div>
</div>

```html
<div class="background-tertiary">...</div>
<div class="background-tertiary-50">...</div>
<div class="background-tertiary-100">...</div>
<div class="background-tertiary-200">...</div>
<div class="background-tertiary-300">...</div>
<div class="background-tertiary-400">...</div>
<div class="background-tertiary-500">...</div>
<div class="background-tertiary-600">...</div>
<div class="background-tertiary-700">...</div>
<div class="background-tertiary-800">...</div>
<div class="background-tertiary-900">...</div>
```

## Indicators

### Error

<div class="padding-xs color-white background-error">Error</div>
<div class="palette">
  <div class="padding-xs color-dark background-error-50">Error<br>50</div>
  <div class="padding-xs color-dark background-error-100">Error<br>100</div>
  <div class="padding-xs color-dark background-error-200">Error<br>200</div>
  <div class="padding-xs color-dark background-error-300">Error<br>300</div>
  <div class="padding-xs color-white background-error-400">Error<br>400</div>
  <div class="padding-xs color-white background-error-500">Error<br>500</div>
  <div class="padding-xs color-white background-error-600">Error<br>600</div>
  <div class="padding-xs color-white background-error-700">Error<br>700</div>
  <div class="padding-xs color-white background-error-800">Error<br>800</div>
  <div class="padding-xs color-white background-error-900">Error<br>900</div>
</div>

```html
<div class="background-error">...</div>
<div class="background-error-50">...</div>
<div class="background-error-100">...</div>
<div class="background-error-200">...</div>
<div class="background-error-300">...</div>
<div class="background-error-400">...</div>
<div class="background-error-500">...</div>
<div class="background-error-600">...</div>
<div class="background-error-700">...</div>
<div class="background-error-800">...</div>
<div class="background-error-900">...</div>
```

### Warning

<div class="padding-xs color-white background-warning">Warning</div>
<div class="palette">
  <div class="padding-xs color-dark background-warning-50">Warning<br>50</div>
  <div class="padding-xs color-dark background-warning-100">Warning<br>100</div>
  <div class="padding-xs color-dark background-warning-200">Warning<br>200</div>
  <div class="padding-xs color-dark background-warning-300">Warning<br>300</div>
  <div class="padding-xs color-white background-warning-400">Warning<br>400</div>
  <div class="padding-xs color-white background-warning-500">Warning<br>500</div>
  <div class="padding-xs color-white background-warning-600">Warning<br>600</div>
  <div class="padding-xs color-white background-warning-700">Warning<br>700</div>
  <div class="padding-xs color-white background-warning-800">Warning<br>800</div>
  <div class="padding-xs color-white background-warning-900">Warning<br>900</div>
</div>

```html
<div class="background-warning">...</div>
<div class="background-warning-50">...</div>
<div class="background-warning-100">...</div>
<div class="background-warning-200">...</div>
<div class="background-warning-300">...</div>
<div class="background-warning-400">...</div>
<div class="background-warning-500">...</div>
<div class="background-warning-600">...</div>
<div class="background-warning-700">...</div>
<div class="background-warning-800">...</div>
<div class="background-warning-900">...</div>
```

### Success

<div class="padding-xs color-white background-success">Success</div>
<div class="palette">
  <div class="padding-xs color-dark background-success-50">Success<br>50</div>
  <div class="padding-xs color-dark background-success-100">Success<br>100</div>
  <div class="padding-xs color-dark background-success-200">Success<br>200</div>
  <div class="padding-xs color-dark background-success-300">Success<br>300</div>
  <div class="padding-xs color-white background-success-400">Success<br>400</div>
  <div class="padding-xs color-white background-success-500">Success<br>500</div>
  <div class="padding-xs color-white background-success-600">Success<br>600</div>
  <div class="padding-xs color-white background-success-700">Success<br>700</div>
  <div class="padding-xs color-white background-success-800">Success<br>800</div>
  <div class="padding-xs color-white background-success-900">Success<br>900</div>
</div>

```html
<div class="background-success">...</div>
<div class="background-success-50">...</div>
<div class="background-success-100">...</div>
<div class="background-success-200">...</div>
<div class="background-success-300">...</div>
<div class="background-success-400">...</div>
<div class="background-success-500">...</div>
<div class="background-success-600">...</div>
<div class="background-success-700">...</div>
<div class="background-success-800">...</div>
<div class="background-success-900">...</div>
```

### Info

<div class="padding-xs color-white background-info">Info</div>
<div class="palette">
  <div class="padding-xs color-dark background-info-50">Info<br>50</div>
  <div class="padding-xs color-dark background-info-100">Info<br>100</div>
  <div class="padding-xs color-dark background-info-200">Info<br>200</div>
  <div class="padding-xs color-dark background-info-300">Info<br>300</div>
  <div class="padding-xs color-white background-info-400">Info<br>400</div>
  <div class="padding-xs color-white background-info-500">Info<br>500</div>
  <div class="padding-xs color-white background-info-600">Info<br>600</div>
  <div class="padding-xs color-white background-info-700">Info<br>700</div>
  <div class="padding-xs color-white background-info-800">Info<br>800</div>
  <div class="padding-xs color-white background-info-900">Info<br>900</div>
</div>

```html
<div class="background-info">...</div>
<div class="background-info-50">...</div>
<div class="background-info-100">...</div>
<div class="background-info-200">...</div>
<div class="background-info-300">...</div>
<div class="background-info-400">...</div>
<div class="background-info-500">...</div>
<div class="background-info-600">...</div>
<div class="background-info-700">...</div>
<div class="background-info-800">...</div>
<div class="background-info-900">...</div>
```
